Struct MultiPool

pub struct MultiPool<K> { /* private fields */ }
Available on crate feature wayland and Linux only.
This pool manages buffers associated with keys. Only one buffer can be attributed to a given key.

Implementations



impl<K> MultiPool<K>

pub fn new( shm: &impl ProvidesBoundGlobal<WlShm, 1>, ) -> Result<MultiPool<K>, CreatePoolError>

pub fn resize(&mut self, size: usize) -> Result<(), Error>

Resizes the memory pool, notifying the server the pool has changed in size.

The wl_shm protocol only allows the pool to be made bigger. If the new size is smaller than the current size of the pool, this function will do nothing.

pub fn remove<Q>(&mut self, key: &Q) -> Option<BufferSlot<K>>
where Q: PartialEq, K: Borrow<Q>,

Removes the buffer with the given key from the pool and rearranges the others.

pub fn insert<Q>( &mut self, width: i32, stride: i32, height: i32, key: &Q, format: Format, ) -> Result<usize, PoolError>
where K: Borrow<Q>, Q: PartialEq + ToOwned<Owned = K>,

Insert a buffer into the pool.

The parameters are:

  • width: the width of this buffer (in pixels)
  • height: the height of this buffer (in pixels)
  • stride: distance (in bytes) between the beginning of a row and the next one
  • key: a borrowed form of the stored key type
  • format: the encoding format of the pixels.

pub fn get<Q>( &mut self, width: i32, stride: i32, height: i32, key: &Q, format: Format, ) -> Option<(usize, &WlBuffer, &mut [u8])>
where Q: PartialEq, K: Borrow<Q>,

Retreives the buffer associated with the given key.

The parameters are:

  • width: the width of this buffer (in pixels)
  • height: the height of this buffer (in pixels)
  • stride: distance (in bytes) between the beginning of a row and the next one
  • key: a borrowed form of the stored key type
  • format: the encoding format of the pixels.

pub fn create_buffer<Q>( &mut self, width: i32, stride: i32, height: i32, key: &Q, format: Format, ) -> Result<(usize, &WlBuffer, &mut [u8]), PoolError>
where K: Borrow<Q>, Q: PartialEq + ToOwned<Owned = K>,

Returns the buffer associated with the given key and its offset (usize) in the mempool.

The parameters are:

  • width: the width of this buffer (in pixels)
  • height: the height of this buffer (in pixels)
  • stride: distance (in bytes) between the beginning of a row and the next one
  • key: a borrowed form of the stored key type
  • format: the encoding format of the pixels.

The offset can be used to determine whether or not a buffer was moved in the mempool and by consequence if it should be damaged partially or fully.